# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'CacheIdentity',
    'CachePatchSchedule',
    'CacheRedisConfiguration',
    'EnterpriseDatabaseModule',
    'GetCachePatchScheduleResult',
    'GetCacheRedisConfigurationResult',
]

@pulumi.output_type
class CacheIdentity(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "identityIds":
            suggest = "identity_ids"
        elif key == "principalId":
            suggest = "principal_id"
        elif key == "tenantId":
            suggest = "tenant_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CacheIdentity. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CacheIdentity.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CacheIdentity.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 type: str,
                 identity_ids: Optional[Sequence[str]] = None,
                 principal_id: Optional[str] = None,
                 tenant_id: Optional[str] = None):
        """
        :param str type: Specifies the type of Managed Service Identity that should be configured on this Redis Cluster. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        :param Sequence[str] identity_ids: A list of User Assigned Managed Identity IDs to be assigned to this Redis Cluster.
               
               > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        CacheIdentity._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            type=type,
            identity_ids=identity_ids,
            principal_id=principal_id,
            tenant_id=tenant_id,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             type: Optional[str] = None,
             identity_ids: Optional[Sequence[str]] = None,
             principal_id: Optional[str] = None,
             tenant_id: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if type is None:
            raise TypeError("Missing 'type' argument")
        if identity_ids is None and 'identityIds' in kwargs:
            identity_ids = kwargs['identityIds']
        if principal_id is None and 'principalId' in kwargs:
            principal_id = kwargs['principalId']
        if tenant_id is None and 'tenantId' in kwargs:
            tenant_id = kwargs['tenantId']

        _setter("type", type)
        if identity_ids is not None:
            _setter("identity_ids", identity_ids)
        if principal_id is not None:
            _setter("principal_id", principal_id)
        if tenant_id is not None:
            _setter("tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Specifies the type of Managed Service Identity that should be configured on this Redis Cluster. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[Sequence[str]]:
        """
        A list of User Assigned Managed Identity IDs to be assigned to this Redis Cluster.

        > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[str]:
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[str]:
        return pulumi.get(self, "tenant_id")


@pulumi.output_type
class CachePatchSchedule(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dayOfWeek":
            suggest = "day_of_week"
        elif key == "maintenanceWindow":
            suggest = "maintenance_window"
        elif key == "startHourUtc":
            suggest = "start_hour_utc"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CachePatchSchedule. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CachePatchSchedule.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CachePatchSchedule.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 day_of_week: str,
                 maintenance_window: Optional[str] = None,
                 start_hour_utc: Optional[int] = None):
        """
        :param str day_of_week: the Weekday name - possible values include `Monday`, `Tuesday`, `Wednesday` etc.
        :param str maintenance_window: The ISO 8601 timespan which specifies the amount of time the Redis Cache can be updated. Defaults to `PT5H`.
        :param int start_hour_utc: the Start Hour for maintenance in UTC - possible values range from `0 - 23`.
               
               > **Note:** The Patch Window lasts for `5` hours from the `start_hour_utc`.
        """
        CachePatchSchedule._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            day_of_week=day_of_week,
            maintenance_window=maintenance_window,
            start_hour_utc=start_hour_utc,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             day_of_week: Optional[str] = None,
             maintenance_window: Optional[str] = None,
             start_hour_utc: Optional[int] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if day_of_week is None and 'dayOfWeek' in kwargs:
            day_of_week = kwargs['dayOfWeek']
        if day_of_week is None:
            raise TypeError("Missing 'day_of_week' argument")
        if maintenance_window is None and 'maintenanceWindow' in kwargs:
            maintenance_window = kwargs['maintenanceWindow']
        if start_hour_utc is None and 'startHourUtc' in kwargs:
            start_hour_utc = kwargs['startHourUtc']

        _setter("day_of_week", day_of_week)
        if maintenance_window is not None:
            _setter("maintenance_window", maintenance_window)
        if start_hour_utc is not None:
            _setter("start_hour_utc", start_hour_utc)

    @property
    @pulumi.getter(name="dayOfWeek")
    def day_of_week(self) -> str:
        """
        the Weekday name - possible values include `Monday`, `Tuesday`, `Wednesday` etc.
        """
        return pulumi.get(self, "day_of_week")

    @property
    @pulumi.getter(name="maintenanceWindow")
    def maintenance_window(self) -> Optional[str]:
        """
        The ISO 8601 timespan which specifies the amount of time the Redis Cache can be updated. Defaults to `PT5H`.
        """
        return pulumi.get(self, "maintenance_window")

    @property
    @pulumi.getter(name="startHourUtc")
    def start_hour_utc(self) -> Optional[int]:
        """
        the Start Hour for maintenance in UTC - possible values range from `0 - 23`.

        > **Note:** The Patch Window lasts for `5` hours from the `start_hour_utc`.
        """
        return pulumi.get(self, "start_hour_utc")


@pulumi.output_type
class CacheRedisConfiguration(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "aofBackupEnabled":
            suggest = "aof_backup_enabled"
        elif key == "aofStorageConnectionString0":
            suggest = "aof_storage_connection_string0"
        elif key == "aofStorageConnectionString1":
            suggest = "aof_storage_connection_string1"
        elif key == "enableAuthentication":
            suggest = "enable_authentication"
        elif key == "maxfragmentationmemoryReserved":
            suggest = "maxfragmentationmemory_reserved"
        elif key == "maxmemoryDelta":
            suggest = "maxmemory_delta"
        elif key == "maxmemoryPolicy":
            suggest = "maxmemory_policy"
        elif key == "maxmemoryReserved":
            suggest = "maxmemory_reserved"
        elif key == "notifyKeyspaceEvents":
            suggest = "notify_keyspace_events"
        elif key == "rdbBackupEnabled":
            suggest = "rdb_backup_enabled"
        elif key == "rdbBackupFrequency":
            suggest = "rdb_backup_frequency"
        elif key == "rdbBackupMaxSnapshotCount":
            suggest = "rdb_backup_max_snapshot_count"
        elif key == "rdbStorageConnectionString":
            suggest = "rdb_storage_connection_string"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in CacheRedisConfiguration. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        CacheRedisConfiguration.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        CacheRedisConfiguration.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 aof_backup_enabled: Optional[bool] = None,
                 aof_storage_connection_string0: Optional[str] = None,
                 aof_storage_connection_string1: Optional[str] = None,
                 enable_authentication: Optional[bool] = None,
                 maxclients: Optional[int] = None,
                 maxfragmentationmemory_reserved: Optional[int] = None,
                 maxmemory_delta: Optional[int] = None,
                 maxmemory_policy: Optional[str] = None,
                 maxmemory_reserved: Optional[int] = None,
                 notify_keyspace_events: Optional[str] = None,
                 rdb_backup_enabled: Optional[bool] = None,
                 rdb_backup_frequency: Optional[int] = None,
                 rdb_backup_max_snapshot_count: Optional[int] = None,
                 rdb_storage_connection_string: Optional[str] = None):
        """
        :param bool aof_backup_enabled: Enable or disable AOF persistence for this Redis Cache. Defaults to `false`.
               
               > **NOTE:** `aof_backup_enabled` can only be set when SKU is `Premium`.
        :param str aof_storage_connection_string0: First Storage Account connection string for AOF persistence.
        :param str aof_storage_connection_string1: Second Storage Account connection string for AOF persistence.
               
               Example usage:
               
               ```python
               import pulumi
               ```
        :param bool enable_authentication: If set to `false`, the Redis instance will be accessible without authentication. Defaults to `true`.
               
               > **NOTE:** `enable_authentication` can only be set to `false` if a `subnet_id` is specified; and only works if there aren't existing instances within the subnet with `enable_authentication` set to `true`.
        :param int maxclients: Returns the max number of connected clients at the same time.
        :param int maxfragmentationmemory_reserved: Value in megabytes reserved to accommodate for memory fragmentation. Defaults are shown below.
        :param int maxmemory_delta: The max-memory delta for this Redis instance. Defaults are shown below.
        :param str maxmemory_policy: How Redis will select what to remove when `maxmemory` is reached. Defaults are shown below. Defaults to `volatile-lru`.
        :param int maxmemory_reserved: Value in megabytes reserved for non-cache usage e.g. failover. Defaults are shown below.
        :param str notify_keyspace_events: Keyspace notifications allows clients to subscribe to Pub/Sub channels in order to receive events affecting the Redis data set in some way. [Reference](https://redis.io/topics/notifications#configuration)
               
               ```python
               import pulumi
               ```
        :param bool rdb_backup_enabled: Is Backup Enabled? Only supported on Premium SKUs. Defaults to `false`.
               
               > **NOTE:** If `rdb_backup_enabled` set to `true`, `rdb_storage_connection_string` must also be set.
        :param int rdb_backup_frequency: The Backup Frequency in Minutes. Only supported on Premium SKUs. Possible values are: `15`, `30`, `60`, `360`, `720` and `1440`.
        :param int rdb_backup_max_snapshot_count: The maximum number of snapshots to create as a backup. Only supported for Premium SKUs.
        :param str rdb_storage_connection_string: The Connection String to the Storage Account. Only supported for Premium SKUs. In the format: `DefaultEndpointsProtocol=https;BlobEndpoint=${azurerm_storage_account.example.primary_blob_endpoint};AccountName=${azurerm_storage_account.example.name};AccountKey=${azurerm_storage_account.example.primary_access_key}`.
               
               > **NOTE:** There's a bug in the Redis API where the original storage connection string isn't being returned, which [is being tracked in this issue](https://github.com/Azure/azure-rest-api-specs/issues/3037). In the interim you can use [the `ignoreChanges` attribute to ignore changes to this field](https://www.pulumi.com/docs/intro/concepts/programming-model/#ignorechanges) e.g.:
        """
        CacheRedisConfiguration._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            aof_backup_enabled=aof_backup_enabled,
            aof_storage_connection_string0=aof_storage_connection_string0,
            aof_storage_connection_string1=aof_storage_connection_string1,
            enable_authentication=enable_authentication,
            maxclients=maxclients,
            maxfragmentationmemory_reserved=maxfragmentationmemory_reserved,
            maxmemory_delta=maxmemory_delta,
            maxmemory_policy=maxmemory_policy,
            maxmemory_reserved=maxmemory_reserved,
            notify_keyspace_events=notify_keyspace_events,
            rdb_backup_enabled=rdb_backup_enabled,
            rdb_backup_frequency=rdb_backup_frequency,
            rdb_backup_max_snapshot_count=rdb_backup_max_snapshot_count,
            rdb_storage_connection_string=rdb_storage_connection_string,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             aof_backup_enabled: Optional[bool] = None,
             aof_storage_connection_string0: Optional[str] = None,
             aof_storage_connection_string1: Optional[str] = None,
             enable_authentication: Optional[bool] = None,
             maxclients: Optional[int] = None,
             maxfragmentationmemory_reserved: Optional[int] = None,
             maxmemory_delta: Optional[int] = None,
             maxmemory_policy: Optional[str] = None,
             maxmemory_reserved: Optional[int] = None,
             notify_keyspace_events: Optional[str] = None,
             rdb_backup_enabled: Optional[bool] = None,
             rdb_backup_frequency: Optional[int] = None,
             rdb_backup_max_snapshot_count: Optional[int] = None,
             rdb_storage_connection_string: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if aof_backup_enabled is None and 'aofBackupEnabled' in kwargs:
            aof_backup_enabled = kwargs['aofBackupEnabled']
        if aof_storage_connection_string0 is None and 'aofStorageConnectionString0' in kwargs:
            aof_storage_connection_string0 = kwargs['aofStorageConnectionString0']
        if aof_storage_connection_string1 is None and 'aofStorageConnectionString1' in kwargs:
            aof_storage_connection_string1 = kwargs['aofStorageConnectionString1']
        if enable_authentication is None and 'enableAuthentication' in kwargs:
            enable_authentication = kwargs['enableAuthentication']
        if maxfragmentationmemory_reserved is None and 'maxfragmentationmemoryReserved' in kwargs:
            maxfragmentationmemory_reserved = kwargs['maxfragmentationmemoryReserved']
        if maxmemory_delta is None and 'maxmemoryDelta' in kwargs:
            maxmemory_delta = kwargs['maxmemoryDelta']
        if maxmemory_policy is None and 'maxmemoryPolicy' in kwargs:
            maxmemory_policy = kwargs['maxmemoryPolicy']
        if maxmemory_reserved is None and 'maxmemoryReserved' in kwargs:
            maxmemory_reserved = kwargs['maxmemoryReserved']
        if notify_keyspace_events is None and 'notifyKeyspaceEvents' in kwargs:
            notify_keyspace_events = kwargs['notifyKeyspaceEvents']
        if rdb_backup_enabled is None and 'rdbBackupEnabled' in kwargs:
            rdb_backup_enabled = kwargs['rdbBackupEnabled']
        if rdb_backup_frequency is None and 'rdbBackupFrequency' in kwargs:
            rdb_backup_frequency = kwargs['rdbBackupFrequency']
        if rdb_backup_max_snapshot_count is None and 'rdbBackupMaxSnapshotCount' in kwargs:
            rdb_backup_max_snapshot_count = kwargs['rdbBackupMaxSnapshotCount']
        if rdb_storage_connection_string is None and 'rdbStorageConnectionString' in kwargs:
            rdb_storage_connection_string = kwargs['rdbStorageConnectionString']

        if aof_backup_enabled is not None:
            _setter("aof_backup_enabled", aof_backup_enabled)
        if aof_storage_connection_string0 is not None:
            _setter("aof_storage_connection_string0", aof_storage_connection_string0)
        if aof_storage_connection_string1 is not None:
            _setter("aof_storage_connection_string1", aof_storage_connection_string1)
        if enable_authentication is not None:
            _setter("enable_authentication", enable_authentication)
        if maxclients is not None:
            _setter("maxclients", maxclients)
        if maxfragmentationmemory_reserved is not None:
            _setter("maxfragmentationmemory_reserved", maxfragmentationmemory_reserved)
        if maxmemory_delta is not None:
            _setter("maxmemory_delta", maxmemory_delta)
        if maxmemory_policy is not None:
            _setter("maxmemory_policy", maxmemory_policy)
        if maxmemory_reserved is not None:
            _setter("maxmemory_reserved", maxmemory_reserved)
        if notify_keyspace_events is not None:
            _setter("notify_keyspace_events", notify_keyspace_events)
        if rdb_backup_enabled is not None:
            _setter("rdb_backup_enabled", rdb_backup_enabled)
        if rdb_backup_frequency is not None:
            _setter("rdb_backup_frequency", rdb_backup_frequency)
        if rdb_backup_max_snapshot_count is not None:
            _setter("rdb_backup_max_snapshot_count", rdb_backup_max_snapshot_count)
        if rdb_storage_connection_string is not None:
            _setter("rdb_storage_connection_string", rdb_storage_connection_string)

    @property
    @pulumi.getter(name="aofBackupEnabled")
    def aof_backup_enabled(self) -> Optional[bool]:
        """
        Enable or disable AOF persistence for this Redis Cache. Defaults to `false`.

        > **NOTE:** `aof_backup_enabled` can only be set when SKU is `Premium`.
        """
        return pulumi.get(self, "aof_backup_enabled")

    @property
    @pulumi.getter(name="aofStorageConnectionString0")
    def aof_storage_connection_string0(self) -> Optional[str]:
        """
        First Storage Account connection string for AOF persistence.
        """
        return pulumi.get(self, "aof_storage_connection_string0")

    @property
    @pulumi.getter(name="aofStorageConnectionString1")
    def aof_storage_connection_string1(self) -> Optional[str]:
        """
        Second Storage Account connection string for AOF persistence.

        Example usage:

        ```python
        import pulumi
        ```
        """
        return pulumi.get(self, "aof_storage_connection_string1")

    @property
    @pulumi.getter(name="enableAuthentication")
    def enable_authentication(self) -> Optional[bool]:
        """
        If set to `false`, the Redis instance will be accessible without authentication. Defaults to `true`.

        > **NOTE:** `enable_authentication` can only be set to `false` if a `subnet_id` is specified; and only works if there aren't existing instances within the subnet with `enable_authentication` set to `true`.
        """
        return pulumi.get(self, "enable_authentication")

    @property
    @pulumi.getter
    def maxclients(self) -> Optional[int]:
        """
        Returns the max number of connected clients at the same time.
        """
        return pulumi.get(self, "maxclients")

    @property
    @pulumi.getter(name="maxfragmentationmemoryReserved")
    def maxfragmentationmemory_reserved(self) -> Optional[int]:
        """
        Value in megabytes reserved to accommodate for memory fragmentation. Defaults are shown below.
        """
        return pulumi.get(self, "maxfragmentationmemory_reserved")

    @property
    @pulumi.getter(name="maxmemoryDelta")
    def maxmemory_delta(self) -> Optional[int]:
        """
        The max-memory delta for this Redis instance. Defaults are shown below.
        """
        return pulumi.get(self, "maxmemory_delta")

    @property
    @pulumi.getter(name="maxmemoryPolicy")
    def maxmemory_policy(self) -> Optional[str]:
        """
        How Redis will select what to remove when `maxmemory` is reached. Defaults are shown below. Defaults to `volatile-lru`.
        """
        return pulumi.get(self, "maxmemory_policy")

    @property
    @pulumi.getter(name="maxmemoryReserved")
    def maxmemory_reserved(self) -> Optional[int]:
        """
        Value in megabytes reserved for non-cache usage e.g. failover. Defaults are shown below.
        """
        return pulumi.get(self, "maxmemory_reserved")

    @property
    @pulumi.getter(name="notifyKeyspaceEvents")
    def notify_keyspace_events(self) -> Optional[str]:
        """
        Keyspace notifications allows clients to subscribe to Pub/Sub channels in order to receive events affecting the Redis data set in some way. [Reference](https://redis.io/topics/notifications#configuration)

        ```python
        import pulumi
        ```
        """
        return pulumi.get(self, "notify_keyspace_events")

    @property
    @pulumi.getter(name="rdbBackupEnabled")
    def rdb_backup_enabled(self) -> Optional[bool]:
        """
        Is Backup Enabled? Only supported on Premium SKUs. Defaults to `false`.

        > **NOTE:** If `rdb_backup_enabled` set to `true`, `rdb_storage_connection_string` must also be set.
        """
        return pulumi.get(self, "rdb_backup_enabled")

    @property
    @pulumi.getter(name="rdbBackupFrequency")
    def rdb_backup_frequency(self) -> Optional[int]:
        """
        The Backup Frequency in Minutes. Only supported on Premium SKUs. Possible values are: `15`, `30`, `60`, `360`, `720` and `1440`.
        """
        return pulumi.get(self, "rdb_backup_frequency")

    @property
    @pulumi.getter(name="rdbBackupMaxSnapshotCount")
    def rdb_backup_max_snapshot_count(self) -> Optional[int]:
        """
        The maximum number of snapshots to create as a backup. Only supported for Premium SKUs.
        """
        return pulumi.get(self, "rdb_backup_max_snapshot_count")

    @property
    @pulumi.getter(name="rdbStorageConnectionString")
    def rdb_storage_connection_string(self) -> Optional[str]:
        """
        The Connection String to the Storage Account. Only supported for Premium SKUs. In the format: `DefaultEndpointsProtocol=https;BlobEndpoint=${azurerm_storage_account.example.primary_blob_endpoint};AccountName=${azurerm_storage_account.example.name};AccountKey=${azurerm_storage_account.example.primary_access_key}`.

        > **NOTE:** There's a bug in the Redis API where the original storage connection string isn't being returned, which [is being tracked in this issue](https://github.com/Azure/azure-rest-api-specs/issues/3037). In the interim you can use [the `ignoreChanges` attribute to ignore changes to this field](https://www.pulumi.com/docs/intro/concepts/programming-model/#ignorechanges) e.g.:
        """
        return pulumi.get(self, "rdb_storage_connection_string")


@pulumi.output_type
class EnterpriseDatabaseModule(dict):
    def __init__(__self__, *,
                 name: str,
                 args: Optional[str] = None,
                 version: Optional[str] = None):
        """
        :param str name: The name which should be used for this module. Possible values are `RedisBloom`, `RedisTimeSeries`, `RediSearch` and `RedisJSON`. Changing this forces a new Redis Enterprise Database to be created.
        :param str args: Configuration options for the module (e.g. `ERROR_RATE 0.00 INITIAL_SIZE 400`). Changing this forces a new resource to be created. Defaults to `""`.
        """
        EnterpriseDatabaseModule._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            name=name,
            args=args,
            version=version,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             name: Optional[str] = None,
             args: Optional[str] = None,
             version: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if name is None:
            raise TypeError("Missing 'name' argument")

        _setter("name", name)
        if args is not None:
            _setter("args", args)
        if version is not None:
            _setter("version", version)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name which should be used for this module. Possible values are `RedisBloom`, `RedisTimeSeries`, `RediSearch` and `RedisJSON`. Changing this forces a new Redis Enterprise Database to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def args(self) -> Optional[str]:
        """
        Configuration options for the module (e.g. `ERROR_RATE 0.00 INITIAL_SIZE 400`). Changing this forces a new resource to be created. Defaults to `""`.
        """
        return pulumi.get(self, "args")

    @property
    @pulumi.getter
    def version(self) -> Optional[str]:
        return pulumi.get(self, "version")


@pulumi.output_type
class GetCachePatchScheduleResult(dict):
    def __init__(__self__, *,
                 day_of_week: str,
                 maintenance_window: str,
                 start_hour_utc: int):
        """
        :param str day_of_week: the Weekday name for the patch item
        :param str maintenance_window: The ISO 8601 timespan which specifies the amount of time the Redis Cache can be updated.
        :param int start_hour_utc: The Start Hour for maintenance in UTC
        """
        GetCachePatchScheduleResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            day_of_week=day_of_week,
            maintenance_window=maintenance_window,
            start_hour_utc=start_hour_utc,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             day_of_week: Optional[str] = None,
             maintenance_window: Optional[str] = None,
             start_hour_utc: Optional[int] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if day_of_week is None and 'dayOfWeek' in kwargs:
            day_of_week = kwargs['dayOfWeek']
        if day_of_week is None:
            raise TypeError("Missing 'day_of_week' argument")
        if maintenance_window is None and 'maintenanceWindow' in kwargs:
            maintenance_window = kwargs['maintenanceWindow']
        if maintenance_window is None:
            raise TypeError("Missing 'maintenance_window' argument")
        if start_hour_utc is None and 'startHourUtc' in kwargs:
            start_hour_utc = kwargs['startHourUtc']
        if start_hour_utc is None:
            raise TypeError("Missing 'start_hour_utc' argument")

        _setter("day_of_week", day_of_week)
        _setter("maintenance_window", maintenance_window)
        _setter("start_hour_utc", start_hour_utc)

    @property
    @pulumi.getter(name="dayOfWeek")
    def day_of_week(self) -> str:
        """
        the Weekday name for the patch item
        """
        return pulumi.get(self, "day_of_week")

    @property
    @pulumi.getter(name="maintenanceWindow")
    def maintenance_window(self) -> str:
        """
        The ISO 8601 timespan which specifies the amount of time the Redis Cache can be updated.
        """
        return pulumi.get(self, "maintenance_window")

    @property
    @pulumi.getter(name="startHourUtc")
    def start_hour_utc(self) -> int:
        """
        The Start Hour for maintenance in UTC
        """
        return pulumi.get(self, "start_hour_utc")


@pulumi.output_type
class GetCacheRedisConfigurationResult(dict):
    def __init__(__self__, *,
                 aof_backup_enabled: bool,
                 aof_storage_connection_string0: str,
                 aof_storage_connection_string1: str,
                 enable_authentication: bool,
                 maxclients: int,
                 maxfragmentationmemory_reserved: int,
                 maxmemory_delta: int,
                 maxmemory_policy: str,
                 maxmemory_reserved: int,
                 notify_keyspace_events: str,
                 rdb_backup_enabled: bool,
                 rdb_backup_frequency: int,
                 rdb_backup_max_snapshot_count: int,
                 rdb_storage_connection_string: str):
        """
        :param bool enable_authentication: Specifies if authentication is enabled
        :param int maxfragmentationmemory_reserved: Value in megabytes reserved to accommodate for memory fragmentation.
        :param int maxmemory_delta: The max-memory delta for this Redis instance.
        :param str maxmemory_policy: How Redis will select what to remove when `maxmemory` is reached.
        :param int maxmemory_reserved: The value in megabytes reserved for non-cache usage e.g. failover
        :param bool rdb_backup_enabled: Is Backup Enabled? Only supported on Premium SKUs.
        :param int rdb_backup_frequency: The Backup Frequency in Minutes. Only supported on Premium SKUs.
        :param int rdb_backup_max_snapshot_count: The maximum number of snapshots that can be created as a backup.
        :param str rdb_storage_connection_string: The Connection String to the Storage Account. Only supported for Premium SKUs.
        """
        GetCacheRedisConfigurationResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            aof_backup_enabled=aof_backup_enabled,
            aof_storage_connection_string0=aof_storage_connection_string0,
            aof_storage_connection_string1=aof_storage_connection_string1,
            enable_authentication=enable_authentication,
            maxclients=maxclients,
            maxfragmentationmemory_reserved=maxfragmentationmemory_reserved,
            maxmemory_delta=maxmemory_delta,
            maxmemory_policy=maxmemory_policy,
            maxmemory_reserved=maxmemory_reserved,
            notify_keyspace_events=notify_keyspace_events,
            rdb_backup_enabled=rdb_backup_enabled,
            rdb_backup_frequency=rdb_backup_frequency,
            rdb_backup_max_snapshot_count=rdb_backup_max_snapshot_count,
            rdb_storage_connection_string=rdb_storage_connection_string,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             aof_backup_enabled: Optional[bool] = None,
             aof_storage_connection_string0: Optional[str] = None,
             aof_storage_connection_string1: Optional[str] = None,
             enable_authentication: Optional[bool] = None,
             maxclients: Optional[int] = None,
             maxfragmentationmemory_reserved: Optional[int] = None,
             maxmemory_delta: Optional[int] = None,
             maxmemory_policy: Optional[str] = None,
             maxmemory_reserved: Optional[int] = None,
             notify_keyspace_events: Optional[str] = None,
             rdb_backup_enabled: Optional[bool] = None,
             rdb_backup_frequency: Optional[int] = None,
             rdb_backup_max_snapshot_count: Optional[int] = None,
             rdb_storage_connection_string: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if aof_backup_enabled is None and 'aofBackupEnabled' in kwargs:
            aof_backup_enabled = kwargs['aofBackupEnabled']
        if aof_backup_enabled is None:
            raise TypeError("Missing 'aof_backup_enabled' argument")
        if aof_storage_connection_string0 is None and 'aofStorageConnectionString0' in kwargs:
            aof_storage_connection_string0 = kwargs['aofStorageConnectionString0']
        if aof_storage_connection_string0 is None:
            raise TypeError("Missing 'aof_storage_connection_string0' argument")
        if aof_storage_connection_string1 is None and 'aofStorageConnectionString1' in kwargs:
            aof_storage_connection_string1 = kwargs['aofStorageConnectionString1']
        if aof_storage_connection_string1 is None:
            raise TypeError("Missing 'aof_storage_connection_string1' argument")
        if enable_authentication is None and 'enableAuthentication' in kwargs:
            enable_authentication = kwargs['enableAuthentication']
        if enable_authentication is None:
            raise TypeError("Missing 'enable_authentication' argument")
        if maxclients is None:
            raise TypeError("Missing 'maxclients' argument")
        if maxfragmentationmemory_reserved is None and 'maxfragmentationmemoryReserved' in kwargs:
            maxfragmentationmemory_reserved = kwargs['maxfragmentationmemoryReserved']
        if maxfragmentationmemory_reserved is None:
            raise TypeError("Missing 'maxfragmentationmemory_reserved' argument")
        if maxmemory_delta is None and 'maxmemoryDelta' in kwargs:
            maxmemory_delta = kwargs['maxmemoryDelta']
        if maxmemory_delta is None:
            raise TypeError("Missing 'maxmemory_delta' argument")
        if maxmemory_policy is None and 'maxmemoryPolicy' in kwargs:
            maxmemory_policy = kwargs['maxmemoryPolicy']
        if maxmemory_policy is None:
            raise TypeError("Missing 'maxmemory_policy' argument")
        if maxmemory_reserved is None and 'maxmemoryReserved' in kwargs:
            maxmemory_reserved = kwargs['maxmemoryReserved']
        if maxmemory_reserved is None:
            raise TypeError("Missing 'maxmemory_reserved' argument")
        if notify_keyspace_events is None and 'notifyKeyspaceEvents' in kwargs:
            notify_keyspace_events = kwargs['notifyKeyspaceEvents']
        if notify_keyspace_events is None:
            raise TypeError("Missing 'notify_keyspace_events' argument")
        if rdb_backup_enabled is None and 'rdbBackupEnabled' in kwargs:
            rdb_backup_enabled = kwargs['rdbBackupEnabled']
        if rdb_backup_enabled is None:
            raise TypeError("Missing 'rdb_backup_enabled' argument")
        if rdb_backup_frequency is None and 'rdbBackupFrequency' in kwargs:
            rdb_backup_frequency = kwargs['rdbBackupFrequency']
        if rdb_backup_frequency is None:
            raise TypeError("Missing 'rdb_backup_frequency' argument")
        if rdb_backup_max_snapshot_count is None and 'rdbBackupMaxSnapshotCount' in kwargs:
            rdb_backup_max_snapshot_count = kwargs['rdbBackupMaxSnapshotCount']
        if rdb_backup_max_snapshot_count is None:
            raise TypeError("Missing 'rdb_backup_max_snapshot_count' argument")
        if rdb_storage_connection_string is None and 'rdbStorageConnectionString' in kwargs:
            rdb_storage_connection_string = kwargs['rdbStorageConnectionString']
        if rdb_storage_connection_string is None:
            raise TypeError("Missing 'rdb_storage_connection_string' argument")

        _setter("aof_backup_enabled", aof_backup_enabled)
        _setter("aof_storage_connection_string0", aof_storage_connection_string0)
        _setter("aof_storage_connection_string1", aof_storage_connection_string1)
        _setter("enable_authentication", enable_authentication)
        _setter("maxclients", maxclients)
        _setter("maxfragmentationmemory_reserved", maxfragmentationmemory_reserved)
        _setter("maxmemory_delta", maxmemory_delta)
        _setter("maxmemory_policy", maxmemory_policy)
        _setter("maxmemory_reserved", maxmemory_reserved)
        _setter("notify_keyspace_events", notify_keyspace_events)
        _setter("rdb_backup_enabled", rdb_backup_enabled)
        _setter("rdb_backup_frequency", rdb_backup_frequency)
        _setter("rdb_backup_max_snapshot_count", rdb_backup_max_snapshot_count)
        _setter("rdb_storage_connection_string", rdb_storage_connection_string)

    @property
    @pulumi.getter(name="aofBackupEnabled")
    def aof_backup_enabled(self) -> bool:
        return pulumi.get(self, "aof_backup_enabled")

    @property
    @pulumi.getter(name="aofStorageConnectionString0")
    def aof_storage_connection_string0(self) -> str:
        return pulumi.get(self, "aof_storage_connection_string0")

    @property
    @pulumi.getter(name="aofStorageConnectionString1")
    def aof_storage_connection_string1(self) -> str:
        return pulumi.get(self, "aof_storage_connection_string1")

    @property
    @pulumi.getter(name="enableAuthentication")
    def enable_authentication(self) -> bool:
        """
        Specifies if authentication is enabled
        """
        return pulumi.get(self, "enable_authentication")

    @property
    @pulumi.getter
    def maxclients(self) -> int:
        return pulumi.get(self, "maxclients")

    @property
    @pulumi.getter(name="maxfragmentationmemoryReserved")
    def maxfragmentationmemory_reserved(self) -> int:
        """
        Value in megabytes reserved to accommodate for memory fragmentation.
        """
        return pulumi.get(self, "maxfragmentationmemory_reserved")

    @property
    @pulumi.getter(name="maxmemoryDelta")
    def maxmemory_delta(self) -> int:
        """
        The max-memory delta for this Redis instance.
        """
        return pulumi.get(self, "maxmemory_delta")

    @property
    @pulumi.getter(name="maxmemoryPolicy")
    def maxmemory_policy(self) -> str:
        """
        How Redis will select what to remove when `maxmemory` is reached.
        """
        return pulumi.get(self, "maxmemory_policy")

    @property
    @pulumi.getter(name="maxmemoryReserved")
    def maxmemory_reserved(self) -> int:
        """
        The value in megabytes reserved for non-cache usage e.g. failover
        """
        return pulumi.get(self, "maxmemory_reserved")

    @property
    @pulumi.getter(name="notifyKeyspaceEvents")
    def notify_keyspace_events(self) -> str:
        return pulumi.get(self, "notify_keyspace_events")

    @property
    @pulumi.getter(name="rdbBackupEnabled")
    def rdb_backup_enabled(self) -> bool:
        """
        Is Backup Enabled? Only supported on Premium SKUs.
        """
        return pulumi.get(self, "rdb_backup_enabled")

    @property
    @pulumi.getter(name="rdbBackupFrequency")
    def rdb_backup_frequency(self) -> int:
        """
        The Backup Frequency in Minutes. Only supported on Premium SKUs.
        """
        return pulumi.get(self, "rdb_backup_frequency")

    @property
    @pulumi.getter(name="rdbBackupMaxSnapshotCount")
    def rdb_backup_max_snapshot_count(self) -> int:
        """
        The maximum number of snapshots that can be created as a backup.
        """
        return pulumi.get(self, "rdb_backup_max_snapshot_count")

    @property
    @pulumi.getter(name="rdbStorageConnectionString")
    def rdb_storage_connection_string(self) -> str:
        """
        The Connection String to the Storage Account. Only supported for Premium SKUs.
        """
        return pulumi.get(self, "rdb_storage_connection_string")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetIotHubResult',
    'AwaitableGetIotHubResult',
    'get_iot_hub',
    'get_iot_hub_output',
]

@pulumi.output_type
class GetIotHubResult:
    """
    A collection of values returned by getIotHub.
    """
    def __init__(__self__, hostname=None, id=None, identities=None, name=None, resource_group_name=None, tags=None):
        if hostname and not isinstance(hostname, str):
            raise TypeError("Expected argument 'hostname' to be a str")
        pulumi.set(__self__, "hostname", hostname)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identities and not isinstance(identities, list):
            raise TypeError("Expected argument 'identities' to be a list")
        pulumi.set(__self__, "identities", identities)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if resource_group_name and not isinstance(resource_group_name, str):
            raise TypeError("Expected argument 'resource_group_name' to be a str")
        pulumi.set(__self__, "resource_group_name", resource_group_name)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def hostname(self) -> str:
        """
        The Hostname of the IoTHub.
        """
        return pulumi.get(self, "hostname")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def identities(self) -> Sequence['outputs.GetIotHubIdentityResult']:
        """
        A `identity` block as defined below.
        """
        return pulumi.get(self, "identities")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> str:
        return pulumi.get(self, "resource_group_name")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        return pulumi.get(self, "tags")


class AwaitableGetIotHubResult(GetIotHubResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIotHubResult(
            hostname=self.hostname,
            id=self.id,
            identities=self.identities,
            name=self.name,
            resource_group_name=self.resource_group_name,
            tags=self.tags)


def get_iot_hub(name: Optional[str] = None,
                resource_group_name: Optional[str] = None,
                tags: Optional[Mapping[str, str]] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIotHubResult:
    """
    Use this data source to access information about an existing IoTHub.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.iot.get_iot_hub(name="existing",
        resource_group_name="existing")
    pulumi.export("id", example.id)
    ```


    :param str name: The name of this IoTHub.
    :param str resource_group_name: The name of the Resource Group where the IoTHub exists.
    :param Mapping[str, str] tags: A mapping of tags which should be assigned to the IoTHub.
    """
    __args__ = dict()
    __args__['name'] = name
    __args__['resourceGroupName'] = resource_group_name
    __args__['tags'] = tags
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('azure:iot/getIotHub:getIotHub', __args__, opts=opts, typ=GetIotHubResult).value

    return AwaitableGetIotHubResult(
        hostname=pulumi.get(__ret__, 'hostname'),
        id=pulumi.get(__ret__, 'id'),
        identities=pulumi.get(__ret__, 'identities'),
        name=pulumi.get(__ret__, 'name'),
        resource_group_name=pulumi.get(__ret__, 'resource_group_name'),
        tags=pulumi.get(__ret__, 'tags'))


@_utilities.lift_output_func(get_iot_hub)
def get_iot_hub_output(name: Optional[pulumi.Input[str]] = None,
                       resource_group_name: Optional[pulumi.Input[str]] = None,
                       tags: Optional[pulumi.Input[Optional[Mapping[str, str]]]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetIotHubResult]:
    """
    Use this data source to access information about an existing IoTHub.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_azure as azure

    example = azure.iot.get_iot_hub(name="existing",
        resource_group_name="existing")
    pulumi.export("id", example.id)
    ```


    :param str name: The name of this IoTHub.
    :param str resource_group_name: The name of the Resource Group where the IoTHub exists.
    :param Mapping[str, str] tags: A mapping of tags which should be assigned to the IoTHub.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['IntegrationAccountBatchConfigurationArgs', 'IntegrationAccountBatchConfiguration']

@pulumi.input_type
class IntegrationAccountBatchConfigurationArgs:
    def __init__(__self__, *,
                 batch_group_name: pulumi.Input[str],
                 integration_account_name: pulumi.Input[str],
                 release_criteria: pulumi.Input['IntegrationAccountBatchConfigurationReleaseCriteriaArgs'],
                 resource_group_name: pulumi.Input[str],
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a IntegrationAccountBatchConfiguration resource.
        :param pulumi.Input[str] batch_group_name: The batch group name of the Logic App Integration Batch Configuration. Changing this forces a new resource to be created.
        :param pulumi.Input[str] integration_account_name: The name of the Logic App Integration Account. Changing this forces a new resource to be created.
        :param pulumi.Input['IntegrationAccountBatchConfigurationReleaseCriteriaArgs'] release_criteria: A `release_criteria` block as documented below, which is used to select the criteria to meet before processing each batch.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Logic App Integration Account Batch Configuration should exist. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: A JSON mapping of any Metadata for this Logic App Integration Account Batch Configuration.
        :param pulumi.Input[str] name: The name which should be used for this Logic App Integration Account Batch Configuration. Only Alphanumeric characters allowed. Changing this forces a new resource to be created.
        """
        IntegrationAccountBatchConfigurationArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            batch_group_name=batch_group_name,
            integration_account_name=integration_account_name,
            release_criteria=release_criteria,
            resource_group_name=resource_group_name,
            metadata=metadata,
            name=name,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             batch_group_name: Optional[pulumi.Input[str]] = None,
             integration_account_name: Optional[pulumi.Input[str]] = None,
             release_criteria: Optional[pulumi.Input['IntegrationAccountBatchConfigurationReleaseCriteriaArgs']] = None,
             resource_group_name: Optional[pulumi.Input[str]] = None,
             metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
             name: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if batch_group_name is None and 'batchGroupName' in kwargs:
            batch_group_name = kwargs['batchGroupName']
        if batch_group_name is None:
            raise TypeError("Missing 'batch_group_name' argument")
        if integration_account_name is None and 'integrationAccountName' in kwargs:
            integration_account_name = kwargs['integrationAccountName']
        if integration_account_name is None:
            raise TypeError("Missing 'integration_account_name' argument")
        if release_criteria is None and 'releaseCriteria' in kwargs:
            release_criteria = kwargs['releaseCriteria']
        if release_criteria is None:
            raise TypeError("Missing 'release_criteria' argument")
        if resource_group_name is None and 'resourceGroupName' in kwargs:
            resource_group_name = kwargs['resourceGroupName']
        if resource_group_name is None:
            raise TypeError("Missing 'resource_group_name' argument")

        _setter("batch_group_name", batch_group_name)
        _setter("integration_account_name", integration_account_name)
        _setter("release_criteria", release_criteria)
        _setter("resource_group_name", resource_group_name)
        if metadata is not None:
            _setter("metadata", metadata)
        if name is not None:
            _setter("name", name)

    @property
    @pulumi.getter(name="batchGroupName")
    def batch_group_name(self) -> pulumi.Input[str]:
        """
        The batch group name of the Logic App Integration Batch Configuration. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "batch_group_name")

    @batch_group_name.setter
    def batch_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "batch_group_name", value)

    @property
    @pulumi.getter(name="integrationAccountName")
    def integration_account_name(self) -> pulumi.Input[str]:
        """
        The name of the Logic App Integration Account. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "integration_account_name")

    @integration_account_name.setter
    def integration_account_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "integration_account_name", value)

    @property
    @pulumi.getter(name="releaseCriteria")
    def release_criteria(self) -> pulumi.Input['IntegrationAccountBatchConfigurationReleaseCriteriaArgs']:
        """
        A `release_criteria` block as documented below, which is used to select the criteria to meet before processing each batch.
        """
        return pulumi.get(self, "release_criteria")

    @release_criteria.setter
    def release_criteria(self, value: pulumi.Input['IntegrationAccountBatchConfigurationReleaseCriteriaArgs']):
        pulumi.set(self, "release_criteria", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Input[str]:
        """
        The name of the Resource Group where the Logic App Integration Account Batch Configuration should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "resource_group_name", value)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A JSON mapping of any Metadata for this Logic App Integration Account Batch Configuration.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Logic App Integration Account Batch Configuration. Only Alphanumeric characters allowed. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _IntegrationAccountBatchConfigurationState:
    def __init__(__self__, *,
                 batch_group_name: Optional[pulumi.Input[str]] = None,
                 integration_account_name: Optional[pulumi.Input[str]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 release_criteria: Optional[pulumi.Input['IntegrationAccountBatchConfigurationReleaseCriteriaArgs']] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering IntegrationAccountBatchConfiguration resources.
        :param pulumi.Input[str] batch_group_name: The batch group name of the Logic App Integration Batch Configuration. Changing this forces a new resource to be created.
        :param pulumi.Input[str] integration_account_name: The name of the Logic App Integration Account. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: A JSON mapping of any Metadata for this Logic App Integration Account Batch Configuration.
        :param pulumi.Input[str] name: The name which should be used for this Logic App Integration Account Batch Configuration. Only Alphanumeric characters allowed. Changing this forces a new resource to be created.
        :param pulumi.Input['IntegrationAccountBatchConfigurationReleaseCriteriaArgs'] release_criteria: A `release_criteria` block as documented below, which is used to select the criteria to meet before processing each batch.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Logic App Integration Account Batch Configuration should exist. Changing this forces a new resource to be created.
        """
        _IntegrationAccountBatchConfigurationState._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            batch_group_name=batch_group_name,
            integration_account_name=integration_account_name,
            metadata=metadata,
            name=name,
            release_criteria=release_criteria,
            resource_group_name=resource_group_name,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             batch_group_name: Optional[pulumi.Input[str]] = None,
             integration_account_name: Optional[pulumi.Input[str]] = None,
             metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
             name: Optional[pulumi.Input[str]] = None,
             release_criteria: Optional[pulumi.Input['IntegrationAccountBatchConfigurationReleaseCriteriaArgs']] = None,
             resource_group_name: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if batch_group_name is None and 'batchGroupName' in kwargs:
            batch_group_name = kwargs['batchGroupName']
        if integration_account_name is None and 'integrationAccountName' in kwargs:
            integration_account_name = kwargs['integrationAccountName']
        if release_criteria is None and 'releaseCriteria' in kwargs:
            release_criteria = kwargs['releaseCriteria']
        if resource_group_name is None and 'resourceGroupName' in kwargs:
            resource_group_name = kwargs['resourceGroupName']

        if batch_group_name is not None:
            _setter("batch_group_name", batch_group_name)
        if integration_account_name is not None:
            _setter("integration_account_name", integration_account_name)
        if metadata is not None:
            _setter("metadata", metadata)
        if name is not None:
            _setter("name", name)
        if release_criteria is not None:
            _setter("release_criteria", release_criteria)
        if resource_group_name is not None:
            _setter("resource_group_name", resource_group_name)

    @property
    @pulumi.getter(name="batchGroupName")
    def batch_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The batch group name of the Logic App Integration Batch Configuration. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "batch_group_name")

    @batch_group_name.setter
    def batch_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "batch_group_name", value)

    @property
    @pulumi.getter(name="integrationAccountName")
    def integration_account_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Logic App Integration Account. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "integration_account_name")

    @integration_account_name.setter
    def integration_account_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "integration_account_name", value)

    @property
    @pulumi.getter
    def metadata(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]:
        """
        A JSON mapping of any Metadata for this Logic App Integration Account Batch Configuration.
        """
        return pulumi.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]]):
        pulumi.set(self, "metadata", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name which should be used for this Logic App Integration Account Batch Configuration. Only Alphanumeric characters allowed. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="releaseCriteria")
    def release_criteria(self) -> Optional[pulumi.Input['IntegrationAccountBatchConfigurationReleaseCriteriaArgs']]:
        """
        A `release_criteria` block as documented below, which is used to select the criteria to meet before processing each batch.
        """
        return pulumi.get(self, "release_criteria")

    @release_criteria.setter
    def release_criteria(self, value: Optional[pulumi.Input['IntegrationAccountBatchConfigurationReleaseCriteriaArgs']]):
        pulumi.set(self, "release_criteria", value)

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the Resource Group where the Logic App Integration Account Batch Configuration should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")

    @resource_group_name.setter
    def resource_group_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "resource_group_name", value)


class IntegrationAccountBatchConfiguration(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 batch_group_name: Optional[pulumi.Input[str]] = None,
                 integration_account_name: Optional[pulumi.Input[str]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 release_criteria: Optional[pulumi.Input[pulumi.InputType['IntegrationAccountBatchConfigurationReleaseCriteriaArgs']]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Manages a Logic App Integration Account Batch Configuration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_integration_account = azure.logicapps.IntegrationAccount("exampleIntegrationAccount",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            sku_name="Standard")
        example_integration_account_batch_configuration = azure.logicapps.IntegrationAccountBatchConfiguration("exampleIntegrationAccountBatchConfiguration",
            resource_group_name=example_resource_group.name,
            integration_account_name=example_integration_account.name,
            batch_group_name="TestBatchGroup",
            release_criteria=azure.logicapps.IntegrationAccountBatchConfigurationReleaseCriteriaArgs(
                message_count=80,
            ))
        ```

        ## Import

        Logic App Integration Account Batch Configurations can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:logicapps/integrationAccountBatchConfiguration:IntegrationAccountBatchConfiguration example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Logic/integrationAccounts/account1/batchConfigurations/batchConfiguration1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] batch_group_name: The batch group name of the Logic App Integration Batch Configuration. Changing this forces a new resource to be created.
        :param pulumi.Input[str] integration_account_name: The name of the Logic App Integration Account. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: A JSON mapping of any Metadata for this Logic App Integration Account Batch Configuration.
        :param pulumi.Input[str] name: The name which should be used for this Logic App Integration Account Batch Configuration. Only Alphanumeric characters allowed. Changing this forces a new resource to be created.
        :param pulumi.Input[pulumi.InputType['IntegrationAccountBatchConfigurationReleaseCriteriaArgs']] release_criteria: A `release_criteria` block as documented below, which is used to select the criteria to meet before processing each batch.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Logic App Integration Account Batch Configuration should exist. Changing this forces a new resource to be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: IntegrationAccountBatchConfigurationArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manages a Logic App Integration Account Batch Configuration.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_azure as azure

        example_resource_group = azure.core.ResourceGroup("exampleResourceGroup", location="West Europe")
        example_integration_account = azure.logicapps.IntegrationAccount("exampleIntegrationAccount",
            location=example_resource_group.location,
            resource_group_name=example_resource_group.name,
            sku_name="Standard")
        example_integration_account_batch_configuration = azure.logicapps.IntegrationAccountBatchConfiguration("exampleIntegrationAccountBatchConfiguration",
            resource_group_name=example_resource_group.name,
            integration_account_name=example_integration_account.name,
            batch_group_name="TestBatchGroup",
            release_criteria=azure.logicapps.IntegrationAccountBatchConfigurationReleaseCriteriaArgs(
                message_count=80,
            ))
        ```

        ## Import

        Logic App Integration Account Batch Configurations can be imported using the `resource id`, e.g.

        ```sh
         $ pulumi import azure:logicapps/integrationAccountBatchConfiguration:IntegrationAccountBatchConfiguration example /subscriptions/00000000-0000-0000-0000-000000000000/resourceGroups/group1/providers/Microsoft.Logic/integrationAccounts/account1/batchConfigurations/batchConfiguration1
        ```

        :param str resource_name: The name of the resource.
        :param IntegrationAccountBatchConfigurationArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(IntegrationAccountBatchConfigurationArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            kwargs = kwargs or {}
            def _setter(key, value):
                kwargs[key] = value
            IntegrationAccountBatchConfigurationArgs._configure(_setter, **kwargs)
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 batch_group_name: Optional[pulumi.Input[str]] = None,
                 integration_account_name: Optional[pulumi.Input[str]] = None,
                 metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 release_criteria: Optional[pulumi.Input[pulumi.InputType['IntegrationAccountBatchConfigurationReleaseCriteriaArgs']]] = None,
                 resource_group_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = IntegrationAccountBatchConfigurationArgs.__new__(IntegrationAccountBatchConfigurationArgs)

            if batch_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'batch_group_name'")
            __props__.__dict__["batch_group_name"] = batch_group_name
            if integration_account_name is None and not opts.urn:
                raise TypeError("Missing required property 'integration_account_name'")
            __props__.__dict__["integration_account_name"] = integration_account_name
            __props__.__dict__["metadata"] = metadata
            __props__.__dict__["name"] = name
            release_criteria = _utilities.configure(release_criteria, IntegrationAccountBatchConfigurationReleaseCriteriaArgs, True)
            if release_criteria is None and not opts.urn:
                raise TypeError("Missing required property 'release_criteria'")
            __props__.__dict__["release_criteria"] = release_criteria
            if resource_group_name is None and not opts.urn:
                raise TypeError("Missing required property 'resource_group_name'")
            __props__.__dict__["resource_group_name"] = resource_group_name
        super(IntegrationAccountBatchConfiguration, __self__).__init__(
            'azure:logicapps/integrationAccountBatchConfiguration:IntegrationAccountBatchConfiguration',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            batch_group_name: Optional[pulumi.Input[str]] = None,
            integration_account_name: Optional[pulumi.Input[str]] = None,
            metadata: Optional[pulumi.Input[Mapping[str, pulumi.Input[str]]]] = None,
            name: Optional[pulumi.Input[str]] = None,
            release_criteria: Optional[pulumi.Input[pulumi.InputType['IntegrationAccountBatchConfigurationReleaseCriteriaArgs']]] = None,
            resource_group_name: Optional[pulumi.Input[str]] = None) -> 'IntegrationAccountBatchConfiguration':
        """
        Get an existing IntegrationAccountBatchConfiguration resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] batch_group_name: The batch group name of the Logic App Integration Batch Configuration. Changing this forces a new resource to be created.
        :param pulumi.Input[str] integration_account_name: The name of the Logic App Integration Account. Changing this forces a new resource to be created.
        :param pulumi.Input[Mapping[str, pulumi.Input[str]]] metadata: A JSON mapping of any Metadata for this Logic App Integration Account Batch Configuration.
        :param pulumi.Input[str] name: The name which should be used for this Logic App Integration Account Batch Configuration. Only Alphanumeric characters allowed. Changing this forces a new resource to be created.
        :param pulumi.Input[pulumi.InputType['IntegrationAccountBatchConfigurationReleaseCriteriaArgs']] release_criteria: A `release_criteria` block as documented below, which is used to select the criteria to meet before processing each batch.
        :param pulumi.Input[str] resource_group_name: The name of the Resource Group where the Logic App Integration Account Batch Configuration should exist. Changing this forces a new resource to be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _IntegrationAccountBatchConfigurationState.__new__(_IntegrationAccountBatchConfigurationState)

        __props__.__dict__["batch_group_name"] = batch_group_name
        __props__.__dict__["integration_account_name"] = integration_account_name
        __props__.__dict__["metadata"] = metadata
        __props__.__dict__["name"] = name
        __props__.__dict__["release_criteria"] = release_criteria
        __props__.__dict__["resource_group_name"] = resource_group_name
        return IntegrationAccountBatchConfiguration(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="batchGroupName")
    def batch_group_name(self) -> pulumi.Output[str]:
        """
        The batch group name of the Logic App Integration Batch Configuration. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "batch_group_name")

    @property
    @pulumi.getter(name="integrationAccountName")
    def integration_account_name(self) -> pulumi.Output[str]:
        """
        The name of the Logic App Integration Account. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "integration_account_name")

    @property
    @pulumi.getter
    def metadata(self) -> pulumi.Output[Optional[Mapping[str, str]]]:
        """
        A JSON mapping of any Metadata for this Logic App Integration Account Batch Configuration.
        """
        return pulumi.get(self, "metadata")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name which should be used for this Logic App Integration Account Batch Configuration. Only Alphanumeric characters allowed. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="releaseCriteria")
    def release_criteria(self) -> pulumi.Output['outputs.IntegrationAccountBatchConfigurationReleaseCriteria']:
        """
        A `release_criteria` block as documented below, which is used to select the criteria to meet before processing each batch.
        """
        return pulumi.get(self, "release_criteria")

    @property
    @pulumi.getter(name="resourceGroupName")
    def resource_group_name(self) -> pulumi.Output[str]:
        """
        The name of the Resource Group where the Logic App Integration Account Batch Configuration should exist. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "resource_group_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetComputeMachineAgentConfigurationResult',
    'GetComputeMachineAgentConfigurationExtensionsAllowListResult',
    'GetComputeMachineAgentConfigurationExtensionsBlockListResult',
    'GetComputeMachineCloudMetadataResult',
    'GetComputeMachineErrorDetailResult',
    'GetComputeMachineErrorDetailAdditionalInfoResult',
    'GetComputeMachineIdentityResult',
    'GetComputeMachineLocationDataResult',
    'GetComputeMachineOsProfileResult',
    'GetComputeMachineOsProfileLinuxConfigurationResult',
    'GetComputeMachineOsProfileLinuxConfigurationPatchSettingResult',
    'GetComputeMachineOsProfileWindowsConfigurationResult',
    'GetComputeMachineOsProfileWindowsConfigurationPatchSettingResult',
    'GetComputeMachineServiceStatusResult',
    'GetComputeMachineServiceStatusExtensionServiceResult',
    'GetComputeMachineServiceStatusGuestConfigurationServiceResult',
]

@pulumi.output_type
class GetComputeMachineAgentConfigurationResult(dict):
    def __init__(__self__, *,
                 extensions_allow_lists: Sequence['outputs.GetComputeMachineAgentConfigurationExtensionsAllowListResult'],
                 extensions_block_lists: Sequence['outputs.GetComputeMachineAgentConfigurationExtensionsBlockListResult'],
                 extensions_enabled: bool,
                 guest_configuration_enabled: bool,
                 incoming_connections_ports: Sequence[str],
                 proxy_bypasses: Sequence[str],
                 proxy_url: str):
        """
        :param Sequence['GetComputeMachineAgentConfigurationExtensionsAllowListArgs'] extensions_allow_lists: A `extensions_allow_list` block as defined below.
        :param Sequence['GetComputeMachineAgentConfigurationExtensionsBlockListArgs'] extensions_block_lists: A `extensions_block_list` block as defined below.
        :param bool extensions_enabled: Specifies whether the extension service is enabled or disabled.
        :param bool guest_configuration_enabled: Specified whether the guest configuration service is enabled or disabled.
        :param Sequence[str] incoming_connections_ports: Specifies the list of ports that the agent will be able to listen on.
        :param Sequence[str] proxy_bypasses: List of service names which should not use the specified proxy server.
        :param str proxy_url: Specifies the URL of the proxy to be used.
        """
        GetComputeMachineAgentConfigurationResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            extensions_allow_lists=extensions_allow_lists,
            extensions_block_lists=extensions_block_lists,
            extensions_enabled=extensions_enabled,
            guest_configuration_enabled=guest_configuration_enabled,
            incoming_connections_ports=incoming_connections_ports,
            proxy_bypasses=proxy_bypasses,
            proxy_url=proxy_url,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             extensions_allow_lists: Optional[Sequence['outputs.GetComputeMachineAgentConfigurationExtensionsAllowListResult']] = None,
             extensions_block_lists: Optional[Sequence['outputs.GetComputeMachineAgentConfigurationExtensionsBlockListResult']] = None,
             extensions_enabled: Optional[bool] = None,
             guest_configuration_enabled: Optional[bool] = None,
             incoming_connections_ports: Optional[Sequence[str]] = None,
             proxy_bypasses: Optional[Sequence[str]] = None,
             proxy_url: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if extensions_allow_lists is None and 'extensionsAllowLists' in kwargs:
            extensions_allow_lists = kwargs['extensionsAllowLists']
        if extensions_allow_lists is None:
            raise TypeError("Missing 'extensions_allow_lists' argument")
        if extensions_block_lists is None and 'extensionsBlockLists' in kwargs:
            extensions_block_lists = kwargs['extensionsBlockLists']
        if extensions_block_lists is None:
            raise TypeError("Missing 'extensions_block_lists' argument")
        if extensions_enabled is None and 'extensionsEnabled' in kwargs:
            extensions_enabled = kwargs['extensionsEnabled']
        if extensions_enabled is None:
            raise TypeError("Missing 'extensions_enabled' argument")
        if guest_configuration_enabled is None and 'guestConfigurationEnabled' in kwargs:
            guest_configuration_enabled = kwargs['guestConfigurationEnabled']
        if guest_configuration_enabled is None:
            raise TypeError("Missing 'guest_configuration_enabled' argument")
        if incoming_connections_ports is None and 'incomingConnectionsPorts' in kwargs:
            incoming_connections_ports = kwargs['incomingConnectionsPorts']
        if incoming_connections_ports is None:
            raise TypeError("Missing 'incoming_connections_ports' argument")
        if proxy_bypasses is None and 'proxyBypasses' in kwargs:
            proxy_bypasses = kwargs['proxyBypasses']
        if proxy_bypasses is None:
            raise TypeError("Missing 'proxy_bypasses' argument")
        if proxy_url is None and 'proxyUrl' in kwargs:
            proxy_url = kwargs['proxyUrl']
        if proxy_url is None:
            raise TypeError("Missing 'proxy_url' argument")

        _setter("extensions_allow_lists", extensions_allow_lists)
        _setter("extensions_block_lists", extensions_block_lists)
        _setter("extensions_enabled", extensions_enabled)
        _setter("guest_configuration_enabled", guest_configuration_enabled)
        _setter("incoming_connections_ports", incoming_connections_ports)
        _setter("proxy_bypasses", proxy_bypasses)
        _setter("proxy_url", proxy_url)

    @property
    @pulumi.getter(name="extensionsAllowLists")
    def extensions_allow_lists(self) -> Sequence['outputs.GetComputeMachineAgentConfigurationExtensionsAllowListResult']:
        """
        A `extensions_allow_list` block as defined below.
        """
        return pulumi.get(self, "extensions_allow_lists")

    @property
    @pulumi.getter(name="extensionsBlockLists")
    def extensions_block_lists(self) -> Sequence['outputs.GetComputeMachineAgentConfigurationExtensionsBlockListResult']:
        """
        A `extensions_block_list` block as defined below.
        """
        return pulumi.get(self, "extensions_block_lists")

    @property
    @pulumi.getter(name="extensionsEnabled")
    def extensions_enabled(self) -> bool:
        """
        Specifies whether the extension service is enabled or disabled.
        """
        return pulumi.get(self, "extensions_enabled")

    @property
    @pulumi.getter(name="guestConfigurationEnabled")
    def guest_configuration_enabled(self) -> bool:
        """
        Specified whether the guest configuration service is enabled or disabled.
        """
        return pulumi.get(self, "guest_configuration_enabled")

    @property
    @pulumi.getter(name="incomingConnectionsPorts")
    def incoming_connections_ports(self) -> Sequence[str]:
        """
        Specifies the list of ports that the agent will be able to listen on.
        """
        return pulumi.get(self, "incoming_connections_ports")

    @property
    @pulumi.getter(name="proxyBypasses")
    def proxy_bypasses(self) -> Sequence[str]:
        """
        List of service names which should not use the specified proxy server.
        """
        return pulumi.get(self, "proxy_bypasses")

    @property
    @pulumi.getter(name="proxyUrl")
    def proxy_url(self) -> str:
        """
        Specifies the URL of the proxy to be used.
        """
        return pulumi.get(self, "proxy_url")


@pulumi.output_type
class GetComputeMachineAgentConfigurationExtensionsAllowListResult(dict):
    def __init__(__self__, *,
                 publisher: str,
                 type: str):
        """
        :param str publisher: Publisher of the extension.
        :param str type: The identity type.
        """
        GetComputeMachineAgentConfigurationExtensionsAllowListResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            publisher=publisher,
            type=type,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             publisher: Optional[str] = None,
             type: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if publisher is None:
            raise TypeError("Missing 'publisher' argument")
        if type is None:
            raise TypeError("Missing 'type' argument")

        _setter("publisher", publisher)
        _setter("type", type)

    @property
    @pulumi.getter
    def publisher(self) -> str:
        """
        Publisher of the extension.
        """
        return pulumi.get(self, "publisher")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The identity type.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetComputeMachineAgentConfigurationExtensionsBlockListResult(dict):
    def __init__(__self__, *,
                 publisher: str,
                 type: str):
        """
        :param str publisher: Publisher of the extension.
        :param str type: The identity type.
        """
        GetComputeMachineAgentConfigurationExtensionsBlockListResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            publisher=publisher,
            type=type,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             publisher: Optional[str] = None,
             type: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if publisher is None:
            raise TypeError("Missing 'publisher' argument")
        if type is None:
            raise TypeError("Missing 'type' argument")

        _setter("publisher", publisher)
        _setter("type", type)

    @property
    @pulumi.getter
    def publisher(self) -> str:
        """
        Publisher of the extension.
        """
        return pulumi.get(self, "publisher")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The identity type.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetComputeMachineCloudMetadataResult(dict):
    def __init__(__self__, *,
                 provider: str):
        """
        :param str provider: Specifies the cloud provider. For example `Azure`, `AWS` and `GCP`.
        """
        GetComputeMachineCloudMetadataResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            provider=provider,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             provider: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if provider is None:
            raise TypeError("Missing 'provider' argument")

        _setter("provider", provider)

    @property
    @pulumi.getter
    def provider(self) -> str:
        """
        Specifies the cloud provider. For example `Azure`, `AWS` and `GCP`.
        """
        return pulumi.get(self, "provider")


@pulumi.output_type
class GetComputeMachineErrorDetailResult(dict):
    def __init__(__self__, *,
                 additional_infos: Sequence['outputs.GetComputeMachineErrorDetailAdditionalInfoResult'],
                 code: str,
                 message: str,
                 target: str):
        """
        :param Sequence['GetComputeMachineErrorDetailAdditionalInfoArgs'] additional_infos: A `additional_info` block as defined above.
        :param str code: The error code.
        :param str message: The error message.
        :param str target: The error target.
        """
        GetComputeMachineErrorDetailResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            additional_infos=additional_infos,
            code=code,
            message=message,
            target=target,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             additional_infos: Optional[Sequence['outputs.GetComputeMachineErrorDetailAdditionalInfoResult']] = None,
             code: Optional[str] = None,
             message: Optional[str] = None,
             target: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if additional_infos is None and 'additionalInfos' in kwargs:
            additional_infos = kwargs['additionalInfos']
        if additional_infos is None:
            raise TypeError("Missing 'additional_infos' argument")
        if code is None:
            raise TypeError("Missing 'code' argument")
        if message is None:
            raise TypeError("Missing 'message' argument")
        if target is None:
            raise TypeError("Missing 'target' argument")

        _setter("additional_infos", additional_infos)
        _setter("code", code)
        _setter("message", message)
        _setter("target", target)

    @property
    @pulumi.getter(name="additionalInfos")
    def additional_infos(self) -> Sequence['outputs.GetComputeMachineErrorDetailAdditionalInfoResult']:
        """
        A `additional_info` block as defined above.
        """
        return pulumi.get(self, "additional_infos")

    @property
    @pulumi.getter
    def code(self) -> str:
        """
        The error code.
        """
        return pulumi.get(self, "code")

    @property
    @pulumi.getter
    def message(self) -> str:
        """
        The error message.
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter
    def target(self) -> str:
        """
        The error target.
        """
        return pulumi.get(self, "target")


@pulumi.output_type
class GetComputeMachineErrorDetailAdditionalInfoResult(dict):
    def __init__(__self__, *,
                 info: str,
                 type: str):
        """
        :param str info: The additional information message.
        :param str type: The identity type.
        """
        GetComputeMachineErrorDetailAdditionalInfoResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            info=info,
            type=type,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             info: Optional[str] = None,
             type: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if info is None:
            raise TypeError("Missing 'info' argument")
        if type is None:
            raise TypeError("Missing 'type' argument")

        _setter("info", info)
        _setter("type", type)

    @property
    @pulumi.getter
    def info(self) -> str:
        """
        The additional information message.
        """
        return pulumi.get(self, "info")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The identity type.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetComputeMachineIdentityResult(dict):
    def __init__(__self__, *,
                 principal_id: str,
                 tenant_id: str,
                 type: str):
        """
        :param str principal_id: The principal ID of resource identity.
        :param str tenant_id: The tenant ID of resource.
        :param str type: The identity type.
        """
        GetComputeMachineIdentityResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            principal_id=principal_id,
            tenant_id=tenant_id,
            type=type,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             principal_id: Optional[str] = None,
             tenant_id: Optional[str] = None,
             type: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if principal_id is None and 'principalId' in kwargs:
            principal_id = kwargs['principalId']
        if principal_id is None:
            raise TypeError("Missing 'principal_id' argument")
        if tenant_id is None and 'tenantId' in kwargs:
            tenant_id = kwargs['tenantId']
        if tenant_id is None:
            raise TypeError("Missing 'tenant_id' argument")
        if type is None:
            raise TypeError("Missing 'type' argument")

        _setter("principal_id", principal_id)
        _setter("tenant_id", tenant_id)
        _setter("type", type)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> str:
        """
        The principal ID of resource identity.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        """
        The tenant ID of resource.
        """
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The identity type.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetComputeMachineLocationDataResult(dict):
    def __init__(__self__, *,
                 city: str,
                 country_or_region: str,
                 district: str,
                 name: str):
        """
        :param str city: The city or locality where the resource is located.
        :param str country_or_region: The country or region where the resource is located.
        :param str district: The district, state, or province where the resource is located.
        :param str name: The name of this hybrid compute machine.
        """
        GetComputeMachineLocationDataResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            city=city,
            country_or_region=country_or_region,
            district=district,
            name=name,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             city: Optional[str] = None,
             country_or_region: Optional[str] = None,
             district: Optional[str] = None,
             name: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if city is None:
            raise TypeError("Missing 'city' argument")
        if country_or_region is None and 'countryOrRegion' in kwargs:
            country_or_region = kwargs['countryOrRegion']
        if country_or_region is None:
            raise TypeError("Missing 'country_or_region' argument")
        if district is None:
            raise TypeError("Missing 'district' argument")
        if name is None:
            raise TypeError("Missing 'name' argument")

        _setter("city", city)
        _setter("country_or_region", country_or_region)
        _setter("district", district)
        _setter("name", name)

    @property
    @pulumi.getter
    def city(self) -> str:
        """
        The city or locality where the resource is located.
        """
        return pulumi.get(self, "city")

    @property
    @pulumi.getter(name="countryOrRegion")
    def country_or_region(self) -> str:
        """
        The country or region where the resource is located.
        """
        return pulumi.get(self, "country_or_region")

    @property
    @pulumi.getter
    def district(self) -> str:
        """
        The district, state, or province where the resource is located.
        """
        return pulumi.get(self, "district")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of this hybrid compute machine.
        """
        return pulumi.get(self, "name")


@pulumi.output_type
class GetComputeMachineOsProfileResult(dict):
    def __init__(__self__, *,
                 computer_name: str,
                 linux_configurations: Sequence['outputs.GetComputeMachineOsProfileLinuxConfigurationResult'],
                 windows_configurations: Sequence['outputs.GetComputeMachineOsProfileWindowsConfigurationResult']):
        """
        :param str computer_name: Specifies the host OS name of the hybrid machine.
        :param Sequence['GetComputeMachineOsProfileLinuxConfigurationArgs'] linux_configurations: A `linux_configuration` block as defined above.
        :param Sequence['GetComputeMachineOsProfileWindowsConfigurationArgs'] windows_configurations: A `windows_configuration` block as defined below.
        """
        GetComputeMachineOsProfileResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            computer_name=computer_name,
            linux_configurations=linux_configurations,
            windows_configurations=windows_configurations,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             computer_name: Optional[str] = None,
             linux_configurations: Optional[Sequence['outputs.GetComputeMachineOsProfileLinuxConfigurationResult']] = None,
             windows_configurations: Optional[Sequence['outputs.GetComputeMachineOsProfileWindowsConfigurationResult']] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if computer_name is None and 'computerName' in kwargs:
            computer_name = kwargs['computerName']
        if computer_name is None:
            raise TypeError("Missing 'computer_name' argument")
        if linux_configurations is None and 'linuxConfigurations' in kwargs:
            linux_configurations = kwargs['linuxConfigurations']
        if linux_configurations is None:
            raise TypeError("Missing 'linux_configurations' argument")
        if windows_configurations is None and 'windowsConfigurations' in kwargs:
            windows_configurations = kwargs['windowsConfigurations']
        if windows_configurations is None:
            raise TypeError("Missing 'windows_configurations' argument")

        _setter("computer_name", computer_name)
        _setter("linux_configurations", linux_configurations)
        _setter("windows_configurations", windows_configurations)

    @property
    @pulumi.getter(name="computerName")
    def computer_name(self) -> str:
        """
        Specifies the host OS name of the hybrid machine.
        """
        return pulumi.get(self, "computer_name")

    @property
    @pulumi.getter(name="linuxConfigurations")
    def linux_configurations(self) -> Sequence['outputs.GetComputeMachineOsProfileLinuxConfigurationResult']:
        """
        A `linux_configuration` block as defined above.
        """
        return pulumi.get(self, "linux_configurations")

    @property
    @pulumi.getter(name="windowsConfigurations")
    def windows_configurations(self) -> Sequence['outputs.GetComputeMachineOsProfileWindowsConfigurationResult']:
        """
        A `windows_configuration` block as defined below.
        """
        return pulumi.get(self, "windows_configurations")


@pulumi.output_type
class GetComputeMachineOsProfileLinuxConfigurationResult(dict):
    def __init__(__self__, *,
                 patch_settings: Sequence['outputs.GetComputeMachineOsProfileLinuxConfigurationPatchSettingResult']):
        """
        :param Sequence['GetComputeMachineOsProfileLinuxConfigurationPatchSettingArgs'] patch_settings: A `patch_settings` block as defined above.
        """
        GetComputeMachineOsProfileLinuxConfigurationResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            patch_settings=patch_settings,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             patch_settings: Optional[Sequence['outputs.GetComputeMachineOsProfileLinuxConfigurationPatchSettingResult']] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if patch_settings is None and 'patchSettings' in kwargs:
            patch_settings = kwargs['patchSettings']
        if patch_settings is None:
            raise TypeError("Missing 'patch_settings' argument")

        _setter("patch_settings", patch_settings)

    @property
    @pulumi.getter(name="patchSettings")
    def patch_settings(self) -> Sequence['outputs.GetComputeMachineOsProfileLinuxConfigurationPatchSettingResult']:
        """
        A `patch_settings` block as defined above.
        """
        return pulumi.get(self, "patch_settings")


@pulumi.output_type
class GetComputeMachineOsProfileLinuxConfigurationPatchSettingResult(dict):
    def __init__(__self__, *,
                 assessment_mode: str,
                 patch_mode: str):
        """
        :param str assessment_mode: Specifies the assessment mode.
        :param str patch_mode: Specifies the patch mode.
        """
        GetComputeMachineOsProfileLinuxConfigurationPatchSettingResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            assessment_mode=assessment_mode,
            patch_mode=patch_mode,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             assessment_mode: Optional[str] = None,
             patch_mode: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if assessment_mode is None and 'assessmentMode' in kwargs:
            assessment_mode = kwargs['assessmentMode']
        if assessment_mode is None:
            raise TypeError("Missing 'assessment_mode' argument")
        if patch_mode is None and 'patchMode' in kwargs:
            patch_mode = kwargs['patchMode']
        if patch_mode is None:
            raise TypeError("Missing 'patch_mode' argument")

        _setter("assessment_mode", assessment_mode)
        _setter("patch_mode", patch_mode)

    @property
    @pulumi.getter(name="assessmentMode")
    def assessment_mode(self) -> str:
        """
        Specifies the assessment mode.
        """
        return pulumi.get(self, "assessment_mode")

    @property
    @pulumi.getter(name="patchMode")
    def patch_mode(self) -> str:
        """
        Specifies the patch mode.
        """
        return pulumi.get(self, "patch_mode")


@pulumi.output_type
class GetComputeMachineOsProfileWindowsConfigurationResult(dict):
    def __init__(__self__, *,
                 patch_settings: Sequence['outputs.GetComputeMachineOsProfileWindowsConfigurationPatchSettingResult']):
        """
        :param Sequence['GetComputeMachineOsProfileWindowsConfigurationPatchSettingArgs'] patch_settings: A `patch_settings` block as defined above.
        """
        GetComputeMachineOsProfileWindowsConfigurationResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            patch_settings=patch_settings,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             patch_settings: Optional[Sequence['outputs.GetComputeMachineOsProfileWindowsConfigurationPatchSettingResult']] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if patch_settings is None and 'patchSettings' in kwargs:
            patch_settings = kwargs['patchSettings']
        if patch_settings is None:
            raise TypeError("Missing 'patch_settings' argument")

        _setter("patch_settings", patch_settings)

    @property
    @pulumi.getter(name="patchSettings")
    def patch_settings(self) -> Sequence['outputs.GetComputeMachineOsProfileWindowsConfigurationPatchSettingResult']:
        """
        A `patch_settings` block as defined above.
        """
        return pulumi.get(self, "patch_settings")


@pulumi.output_type
class GetComputeMachineOsProfileWindowsConfigurationPatchSettingResult(dict):
    def __init__(__self__, *,
                 assessment_mode: str,
                 patch_mode: str):
        """
        :param str assessment_mode: Specifies the assessment mode.
        :param str patch_mode: Specifies the patch mode.
        """
        GetComputeMachineOsProfileWindowsConfigurationPatchSettingResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            assessment_mode=assessment_mode,
            patch_mode=patch_mode,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             assessment_mode: Optional[str] = None,
             patch_mode: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if assessment_mode is None and 'assessmentMode' in kwargs:
            assessment_mode = kwargs['assessmentMode']
        if assessment_mode is None:
            raise TypeError("Missing 'assessment_mode' argument")
        if patch_mode is None and 'patchMode' in kwargs:
            patch_mode = kwargs['patchMode']
        if patch_mode is None:
            raise TypeError("Missing 'patch_mode' argument")

        _setter("assessment_mode", assessment_mode)
        _setter("patch_mode", patch_mode)

    @property
    @pulumi.getter(name="assessmentMode")
    def assessment_mode(self) -> str:
        """
        Specifies the assessment mode.
        """
        return pulumi.get(self, "assessment_mode")

    @property
    @pulumi.getter(name="patchMode")
    def patch_mode(self) -> str:
        """
        Specifies the patch mode.
        """
        return pulumi.get(self, "patch_mode")


@pulumi.output_type
class GetComputeMachineServiceStatusResult(dict):
    def __init__(__self__, *,
                 extension_services: Sequence['outputs.GetComputeMachineServiceStatusExtensionServiceResult'],
                 guest_configuration_services: Sequence['outputs.GetComputeMachineServiceStatusGuestConfigurationServiceResult']):
        """
        :param Sequence['GetComputeMachineServiceStatusExtensionServiceArgs'] extension_services: A `extension_service` block as defined above.
        :param Sequence['GetComputeMachineServiceStatusGuestConfigurationServiceArgs'] guest_configuration_services: A `guest_configuration_service` block as defined above.
        """
        GetComputeMachineServiceStatusResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            extension_services=extension_services,
            guest_configuration_services=guest_configuration_services,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             extension_services: Optional[Sequence['outputs.GetComputeMachineServiceStatusExtensionServiceResult']] = None,
             guest_configuration_services: Optional[Sequence['outputs.GetComputeMachineServiceStatusGuestConfigurationServiceResult']] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if extension_services is None and 'extensionServices' in kwargs:
            extension_services = kwargs['extensionServices']
        if extension_services is None:
            raise TypeError("Missing 'extension_services' argument")
        if guest_configuration_services is None and 'guestConfigurationServices' in kwargs:
            guest_configuration_services = kwargs['guestConfigurationServices']
        if guest_configuration_services is None:
            raise TypeError("Missing 'guest_configuration_services' argument")

        _setter("extension_services", extension_services)
        _setter("guest_configuration_services", guest_configuration_services)

    @property
    @pulumi.getter(name="extensionServices")
    def extension_services(self) -> Sequence['outputs.GetComputeMachineServiceStatusExtensionServiceResult']:
        """
        A `extension_service` block as defined above.
        """
        return pulumi.get(self, "extension_services")

    @property
    @pulumi.getter(name="guestConfigurationServices")
    def guest_configuration_services(self) -> Sequence['outputs.GetComputeMachineServiceStatusGuestConfigurationServiceResult']:
        """
        A `guest_configuration_service` block as defined above.
        """
        return pulumi.get(self, "guest_configuration_services")


@pulumi.output_type
class GetComputeMachineServiceStatusExtensionServiceResult(dict):
    def __init__(__self__, *,
                 startup_type: str,
                 status: str):
        """
        :param str startup_type: The behavior of the service when the Arc-enabled machine starts up.
        :param str status: The current status of the service.
        """
        GetComputeMachineServiceStatusExtensionServiceResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            startup_type=startup_type,
            status=status,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             startup_type: Optional[str] = None,
             status: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if startup_type is None and 'startupType' in kwargs:
            startup_type = kwargs['startupType']
        if startup_type is None:
            raise TypeError("Missing 'startup_type' argument")
        if status is None:
            raise TypeError("Missing 'status' argument")

        _setter("startup_type", startup_type)
        _setter("status", status)

    @property
    @pulumi.getter(name="startupType")
    def startup_type(self) -> str:
        """
        The behavior of the service when the Arc-enabled machine starts up.
        """
        return pulumi.get(self, "startup_type")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The current status of the service.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetComputeMachineServiceStatusGuestConfigurationServiceResult(dict):
    def __init__(__self__, *,
                 startup_type: str,
                 status: str):
        """
        :param str startup_type: The behavior of the service when the Arc-enabled machine starts up.
        :param str status: The current status of the service.
        """
        GetComputeMachineServiceStatusGuestConfigurationServiceResult._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            startup_type=startup_type,
            status=status,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             startup_type: Optional[str] = None,
             status: Optional[str] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if startup_type is None and 'startupType' in kwargs:
            startup_type = kwargs['startupType']
        if startup_type is None:
            raise TypeError("Missing 'startup_type' argument")
        if status is None:
            raise TypeError("Missing 'status' argument")

        _setter("startup_type", startup_type)
        _setter("status", status)

    @property
    @pulumi.getter(name="startupType")
    def startup_type(self) -> str:
        """
        The behavior of the service when the Arc-enabled machine starts up.
        """
        return pulumi.get(self, "startup_type")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The current status of the service.
        """
        return pulumi.get(self, "status")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Callable, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'InstanceIdentityArgs',
]

@pulumi.input_type
class InstanceIdentityArgs:
    def __init__(__self__, *,
                 type: pulumi.Input[str],
                 identity_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 principal_id: Optional[pulumi.Input[str]] = None,
                 tenant_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] type: Specifies the type of Managed Service Identity that should be configured on this Digital Twins instance. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        :param pulumi.Input[Sequence[pulumi.Input[str]]] identity_ids: A list of User Assigned Managed Identity IDs to be assigned to this Digital Twins instance.
               
               > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        :param pulumi.Input[str] principal_id: The Principal ID associated with this Managed Service Identity.
        :param pulumi.Input[str] tenant_id: The Tenant ID associated with this Managed Service Identity.
        """
        InstanceIdentityArgs._configure(
            lambda key, value: pulumi.set(__self__, key, value),
            type=type,
            identity_ids=identity_ids,
            principal_id=principal_id,
            tenant_id=tenant_id,
        )
    @staticmethod
    def _configure(
             _setter: Callable[[Any, Any], None],
             type: Optional[pulumi.Input[str]] = None,
             identity_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
             principal_id: Optional[pulumi.Input[str]] = None,
             tenant_id: Optional[pulumi.Input[str]] = None,
             opts: Optional[pulumi.ResourceOptions] = None,
             **kwargs):
        if type is None:
            raise TypeError("Missing 'type' argument")
        if identity_ids is None and 'identityIds' in kwargs:
            identity_ids = kwargs['identityIds']
        if principal_id is None and 'principalId' in kwargs:
            principal_id = kwargs['principalId']
        if tenant_id is None and 'tenantId' in kwargs:
            tenant_id = kwargs['tenantId']

        _setter("type", type)
        if identity_ids is not None:
            _setter("identity_ids", identity_ids)
        if principal_id is not None:
            _setter("principal_id", principal_id)
        if tenant_id is not None:
            _setter("tenant_id", tenant_id)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[str]:
        """
        Specifies the type of Managed Service Identity that should be configured on this Digital Twins instance. Possible values are `SystemAssigned`, `UserAssigned`, `SystemAssigned, UserAssigned` (to enable both).
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="identityIds")
    def identity_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        A list of User Assigned Managed Identity IDs to be assigned to this Digital Twins instance.

        > **NOTE:** This is required when `type` is set to `UserAssigned` or `SystemAssigned, UserAssigned`.
        """
        return pulumi.get(self, "identity_ids")

    @identity_ids.setter
    def identity_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "identity_ids", value)

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Principal ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "principal_id")

    @principal_id.setter
    def principal_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "principal_id", value)

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> Optional[pulumi.Input[str]]:
        """
        The Tenant ID associated with this Managed Service Identity.
        """
        return pulumi.get(self, "tenant_id")

    @tenant_id.setter
    def tenant_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tenant_id", value)


